# alarm-notify

- [alarm-notify](#alarm-notify)
  - [Overview](#Overview)
  - [Device Properties](#device-properties)
    - [Configuration](#configuration)
    - [GroupReceivers](#groupreceivers)
    - [PropertyList](#propertylist)
    - [Receivers](#receivers)
    - [SubscribePeriod](#subscribeperiod)
  - [Commands](#commands)
    - [GetAlarmInfo](#getalarminfo)
  - [Attributes](#attributes)
    - [alarmReceivers](#alarmreceivers)
    - [alarmStatus](#alarmstatus)
    - [handlerStatus](#handlerstatus)

The alarm-notify device server is a notification service for the [alarm-handler](https://gitlab.elettra.eu/cs/ds/alarm-handler)

## Overview

alarm-notify connect to a list of alarm-handler devices and subscribes for the change event of their alarm attributes. It checks weather there are Recipients configured in the single alarms, or interested in alarms belonging to a group, or all alarms, then it builds a list of recipients for each alarm state of each email.
When an event is received, if there are recipients configured for the new alarm state, a command on a device is triggered for notification.

A string parameter is passed to the notification command with a semicolon separated list of "key=value" fields, with the following keys:
name=;handler=;values=;time=;url=;msg=;formula=;groups=;shlvd_time=;state=;ack=;time=;dest=;

Example:

```
name=test_alarm1;handler=alarm/handler/0;values={'alarm/test/0/attr':0};time=2022-12-25 00:00:00;url=;msg='Test alarm';formula=(alarm/test/0/attr == 0);groups=gr_ctrl;state=RTNUN;ack=0;dest=a@b.c,d@e.f,;
```

## Device Properties

### Configuration

Array of String.

Device and command to be used for notification (for email see for example [alarm-mail](https://gitlab.elettra.eu/cs/ds/alarm-mail)).

Example:

```
device=name/of/device
command=SendNotification
```

### GroupReceivers

Array of String.

Each row contains recipients interested in some (or all) states of all alarms belonging to a group in the following format:

GroupName=Alarm states 1(comma separated): email addresses (comma separated);Alarm states 2(comma separated): email addresses 2 (comma separated);...

Example:

```
gr_ctrl=OOSRV,SHLVD:a@b.c;ERROR:a@b.c,d@e.f
gr_timing=UNACK,ACKED:a@b.c,d@e.f;RTNUN:g@h.i;NORM:m@n.o
...
```


### PropertyList

Array of String.

List of free properties where to find alarm handlers to manage

Example:

```
AlarmHandler/DeviceList1
AlarmHandler/DeviceList2
...
```

### Receivers

String.

Recipients interested in some (or all) states of all alarms in the following format:

Alarm states1 (comma separated): email addresses (comma separated);Alarm states 2(comma separated): email addresses 2 (comma separated);...

Example:

```
OOSRV,SHLVD:p@q.r;ERROR:s@t.u,v@w.x;...
```


### SubscribePeriod

DevLong.

Period in seconds of thread subscribing (and retrying subscription) for events

## Commands

### GetAlarmInfo

In: DevString

Out: DevVarStringArray

Returns some info about the alarm name passed as parameter.

The following informations are present: name, event state, event error, alarm state, notification counter, recipients of this alarm, recipients of all alarms, recipients of this group

Example:

```
[0]	 Name:        tango://host:10000/alarm/test/0/test_alarm1
[1]	 Event state: SUBSCRIBED
[2]	 Event error: 
[3]	 Alarm State: NORM
[4]	 Counter:     0
[5]	 Dest:        NORM: a@b.c
[6]	 Global Dest: OOSRV,SHLVD:p@q.r;ERROR:s@t.u,v@w.x
[7]	 Group Dest:  UNACK,ACKED:a@b.c,d@e.f;RTNUN:g@h.i;NORM:m@n.o
```


## Attributes

### alarmReceivers

DevString, Spectrum.

List of all managed alarms with recipients in the format "alarm_name - Alarm states1 (comma separated): email addresses (comma separated);Alarm states 2(comma separated): email addresses 2 (comma separated);..."

Example:

```
Read [0]	tango://host:10000/alarm/test/0/test_alarm1 - NORM: a@b.c,m@n.o;OOSRV,SHLVD:p@q.r;ERROR:s@t.u,v@w.x;UNACK,ACKED:a@b.c,d@e.f;RTNUN:g@h.i
Read [1]	...
...
```

### alarmStatus

DevString, Spectrum.

List of all managed alarms with state and notification counter in the format "alarm_name, Alarm states, counter="

Example:

```
tango://host:10000/alarm/test/0/test_alarm1, NORM, counter=1
...
```

### handlerStatus

DevString, Spectrum.

List of all managed alarm handlers with their state in the format "handler device: Tango State"

Example:

```
tango://host:10000/alarm/handler/0: RUNNING
```
